summaryrefslogtreecommitdiffhomepage
path: root/Config.hs
diff options
context:
space:
mode:
Diffstat (limited to 'Config.hs')
-rw-r--r--Config.hs18
1 files changed, 9 insertions, 9 deletions
diff --git a/Config.hs b/Config.hs
index 60ca3b0..1ab01c9 100644
--- a/Config.hs
+++ b/Config.hs
@@ -18,6 +18,7 @@ module Config ( -- * Configuration
, defaultConfig
) where
+import Commands
-- $config
-- Configuration data type and default configuration
@@ -32,12 +33,12 @@ data Config =
, height :: Int -- ^ Window height
, align :: String -- ^ text alignment
, refresh :: Int -- ^ Refresh rate in tenth of seconds
- , commands :: [(String, Int, [String])] -- ^ For setting the refresh rate and
- -- options for the programs to run (optional)
- , sepChar :: String -- ^ The character to be used for indicating
- -- commands in the output template (default '%')
- , template :: String -- ^ The output template
- } deriving (Eq, Show, Read, Ord)
+ , commands :: [(Command,Int)] -- ^ For setting the command, the command argujments
+ -- and refresh rate for the programs to run (optional)
+ , sepChar :: String -- ^ The character to be used for indicating
+ -- commands in the output template (default '%')
+ , template :: String -- ^ The output template
+ } deriving (Read)
-- | The default configuration values
defaultConfig :: Config
@@ -51,8 +52,7 @@ defaultConfig =
, height = 15
, align = "left"
, refresh = 10
- , commands = [("date", 10, [])]
+ , commands = [(Memory [],10)]
, sepChar = "%"
- , template = "Uptime: <fc=#00FF00>%uptime%</fc> ** <fc=#FF0000>%date%</fc>"
+ , template = "Uptime: <fc=#00FF00>%uptime%</fc> ** <fc=#FF0000>%date%</fc> %memory%"
}
-